checked_output

Function checked_output 

pub fn checked_output(command: &mut Command) -> Result<Output>
Execute a prepared command, returning an error with the exit code or signal number and name on failure. Plain Command::output does not reject failed exits.